==> art-rawconverter-debug-1.25.10-1-x86_64.pkg.tar.zst: usr/src/debug/art-rawconverter/ART-1.25.10/rtgui/filethumbnailbuttonset.h <==
/*
 *  This file is part of RawTherapee.
 *
 *  Copyright (c) 2004-2010 Gabor Horvath <hgabor@rawtherapee.com>
 *
 *  RawTherapee is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  RawTherapee is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _FILETHUMBNAILBUTTONSET_
#define _FILETHUMBNAILBUTTONSET_

#include <array>

#include "lwbuttonset.h"
#include <gtkmm.h>
#include "filebrowserentry.h"
#include "rtsurface.h"

class FileBrowserEntry;
class FileThumbnailButtonSet : public LWButtonSet
{

    static bool iconsLoaded;

public:
    static Cairo::RefPtr<RTSurface> rankIcon;
    static Cairo::RefPtr<RTSurface> gRankIcon;
    static Cairo::RefPtr<RTSurface> unRankIcon;
    static Cairo::RefPtr<RTSurface> trashIcon;
    static Cairo::RefPtr<RTSurface> unTrashIcon;
    static Cairo::RefPtr<RTSurface> processIcon;

    static std::array<Cairo::RefPtr<RTSurface>, 6> colorLabelIcon;

    static Glib::ustring processToolTip;
    static Glib::ustring unrankToolTip;
    static Glib::ustring trashToolTip;
    static Glib::ustring untrashToolTip;
    static Glib::ustring colorLabelToolTip;
    static std::array<Glib::ustring, 5> rankToolTip;

    explicit FileThumbnailButtonSet (FileBrowserEntry* myEntry);
    void    setRank (int stars);
    void    setColorLabel (int colorlabel);
    void    setInTrash (bool inTrash);

};

#endif

==> art-rawconverter-debug-1.25.12-1-x86_64.pkg.tar.zst: usr/src/debug/art-rawconverter/ART-1.25.12/rtgui/filethumbnailbuttonset.h <==
/*
 *  This file is part of RawTherapee.
 *
 *  Copyright (c) 2004-2010 Gabor Horvath <hgabor@rawtherapee.com>
 *
 *  RawTherapee is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  RawTherapee is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef _FILETHUMBNAILBUTTONSET_
#define _FILETHUMBNAILBUTTONSET_

#include <array>

#include "filebrowserentry.h"
#include "lwbuttonset.h"
#include "rtsurface.h"
#include <gtkmm.h>

class FileBrowserEntry;
class FileThumbnailButtonSet: public LWButtonSet {

    static bool iconsLoaded;

public:
    static Cairo::RefPtr<RTSurface> rankIcon;
    static Cairo::RefPtr<RTSurface> gRankIcon;
    static Cairo::RefPtr<RTSurface> unRankIcon;
    static Cairo::RefPtr<RTSurface> trashIcon;
    static Cairo::RefPtr<RTSurface> unTrashIcon;
    static Cairo::RefPtr<RTSurface> processIcon;

    static std::array<Cairo::RefPtr<RTSurface>, 6> colorLabelIcon;

    static Glib::ustring processToolTip;
    static Glib::ustring unrankToolTip;
    static Glib::ustring trashToolTip;
    static Glib::ustring untrashToolTip;
    static Glib::ustring colorLabelToolTip;
    static std::array<Glib::ustring, 5> rankToolTip;

    explicit FileThumbnailButtonSet(FileBrowserEntry *myEntry);
    void setRank(int stars);
    void setColorLabel(int colorlabel);
    void setInTrash(bool inTrash);
};

#endif
